import { world } from "@minecraft/server";
const rotations = ['0_degrees', '90_degrees', '180_degrees', '270_degrees'];
const eventProbabilities = [
    { probability: 0.15, event: structure_event },
    { probability: 0.45, event: loot_event },
];

world.afterEvents.entityDie.subscribe((ev) => {
    const { damageSource, deadEntity } = ev;
    if (deadEntity.typeId != 'minecraft:player' && damageSource.damagingEntity?.typeId === 'minecraft:player') probabilityHandler(deadEntity);
})

function probabilityHandler(entity) {
    const randomValue = Math.random();
    let accumulatedProbability = 0;

    for (const { probability, event } of eventProbabilities) {
        accumulatedProbability += probability;
        if (randomValue < accumulatedProbability) {
            event(entity);
            break;
        }
    }
}

async function structure_event(entity) {
    const { x, y, z } = entity.location;
    const rotation = rotations[Math.floor(Math.random() * rotations.length)];
    const structureId = Math.floor(Math.random() * 53) + 1;
    try {
        await entity.dimension.runCommandAsync(`/structure load str_${structureId} ${x} ${y} ${z} ${rotation}`);
    } catch (error) {
        console.error("Error al cargar la estructura:", error);
    }
}
async function loot_event(entity) {
    const { x, y, z } = entity.location;
    const lootId = Math.floor(Math.random() * 460) + 1;
    const dimension = entity.dimension;
    const items = dimension.getEntities({ type: 'minecraft:item', location: { x, y, z }, maxDistance: 10 });
    items.forEach((item) => item.kill());

    try {
        await dimension.runCommandAsync(`/loot spawn ${x} ${y + 0.5} ${z} loot "${lootId}"`);
    } catch (error) {
        console.error("Error al generar el loot:", error);
    }
}

let estructura_index = 25

world.afterEvents.itemUse.subscribe((ev) => {
    const item = ev.itemStack.typeId
    const {x,y,z} = ev.source.location
    if(item == 'minecraft:stick'){
        ev.source.runCommandAsync(`/structure load str_${estructura_index} ${x} ${y} ${z}`);
        world.sendMessage(`str_${estructura_index}`)
    }
    estructura_index = estructura_index +1
})